@@ -2,42 +2,35 @@ from __future__ import annotations
 
 import base64
 import hashlib
-import importlib
 import mimetypes
+import tempfile
 import sys
 import zipfile
 from enum import Enum
 from http.cookiejar import CookieJar
 from pathlib import Path
-from typing import (
-    TYPE_CHECKING,
-    Annotated,
-    Any,
-    BinaryIO,
-    Optional,
-)
-
+from typing import TYPE_CHECKING, Annotated, Any, BinaryIO, Optional, Sequence
+from requests import Response
+from requests.auth import AuthBase
+from requests.models import PreparedRequest
 import msgspec
 import requests
 from architecture.utils.decorators import ensure_module_installed
-
+from typing import (
+    Callable,
+    Iterable,
+    Mapping,
+    MutableMapping,
+    TypeAlias,
+    overload,
+    Literal,
+)
 from typing_extensions import Self
 
 
 if TYPE_CHECKING:
     from fastapi import UploadFile as FastAPIUploadFile
     from _typeshed import SupportsItems, SupportsRead
-    from requests import Response
-    from requests.auth import AuthBase
-    from requests.models import PreparedRequest
-    from typing import (
-        Callable,
-        Iterable,
-        Mapping,
-        MutableMapping,
-        TypeAlias,
-    )
-
     from litestar.datastructures import UploadFile as LitestarUploadFile
 
     _TextMapping: TypeAlias = MutableMapping[str, str]
@@ -107,6 +100,13 @@ class FileExtension(str, Enum):
     HTML = "html"
     TXT = "txt"
     MD = "md"
+    ZIP = "zip"
+    DOCX = "docx"
+    XLSX = "xlsx"
+    CSV = "csv"
+    PPTX = "pptx"
+    TIFF = "tiff"
+    GIF = "gif"
     # Add more extensions as needed
 
 
@@ -310,11 +310,23 @@ class RawFile(msgspec.Struct, frozen=True, gc=False):
         data = stream.read()
         return cls(name=name, contents=data, extension=extension)
 
-    @ensure_module_installed("litestar", "litestar")
+    @overload
     @classmethod
     def from_litestar_upload_file(
-        cls: type[RawFile], file: LitestarUploadFile
-    ) -> RawFile:
+        cls: type[RawFile], file: LitestarUploadFile, is_zip: Literal[False] = False
+    ) -> RawFile: ...
+
+    @overload
+    @classmethod
+    def from_litestar_upload_file(
+        cls: type[RawFile], file: LitestarUploadFile, is_zip: Literal[True]
+    ) -> Sequence[RawFile]: ...
+
+    @classmethod
+    @ensure_module_installed("litestar", "litestar")
+    def from_litestar_upload_file(
+        cls: type[RawFile], file: LitestarUploadFile, is_zip: bool = False
+    ) -> RawFile | Sequence[RawFile]:
         extension: Optional[FileExtension] = cls._get_extension_from_content_type(
             file.content_type
         )
@@ -322,11 +334,20 @@ class RawFile(msgspec.Struct, frozen=True, gc=False):
         if extension is None:
             raise ValueError(f"{file.content_type} is not a supported file type yet.")
 
+        if extension == FileExtension.ZIP:
+            with tempfile.TemporaryDirectory() as temp_dir:
+                file_contents = file.file.read()
+                temp_file_path = Path(temp_dir) / file.filename
+                with open(temp_file_path, "wb") as f:
+                    f.write(file_contents)
+
+                return cls.from_zip(str(temp_file_path))
+
         data = file.file.read()
         return cls(name=file.filename, contents=data, extension=extension)
 
-    @ensure_module_installed("fastapi", "fastapi")
     @classmethod
+    @ensure_module_installed("fastapi", "fastapi")
     def from_fastapi_upload_file(
         cls: type[RawFile], file: FastAPIUploadFile
     ) -> RawFile:
@@ -499,19 +520,55 @@ class RawFile(msgspec.Struct, frozen=True, gc=False):
 
         return cls(name=bucket_name, contents=data, extension=extension)
 
+    @overload
+    @classmethod
+    def from_zip(
+        cls,
+        zip_file_path: str,
+        inner_file_path: None = None,
+    ) -> Sequence[RawFile]: ...
+
+    @overload
     @classmethod
     def from_zip(
         cls,
         zip_file_path: str,
         inner_file_path: str,
-        extension: Optional[FileExtension] = None,
-    ) -> RawFile:
+    ) -> RawFile: ...
+
+    @classmethod
+    def from_zip(
+        cls,
+        zip_file_path: str,
+        inner_file_path: Optional[str] = None,
+    ) -> Sequence[RawFile] | RawFile:
         with zipfile.ZipFile(zip_file_path, "r") as zip_ref:
-            with zip_ref.open(inner_file_path) as file:
-                data = file.read()
-                if not extension:
-                    extension = FileExtension(Path(inner_file_path).suffix.lstrip("."))
-                return cls(name=inner_file_path, contents=data, extension=extension)
+            if inner_file_path:
+                try:
+                    with zip_ref.open(inner_file_path) as file:
+                        data = file.read()
+                        file_extension = FileExtension(
+                            Path(inner_file_path).suffix.lstrip(".")
+                        )
+                        return cls(
+                            name=inner_file_path,
+                            contents=data,
+                            extension=file_extension,
+                        )
+                except KeyError:
+                    raise FileNotFoundError(
+                        f"File '{inner_file_path}' not found in zip archive '{zip_file_path}'"
+                    )
+
+            raw_files = []
+            for inner_file in zip_ref.namelist():
+                with zip_ref.open(inner_file) as file:
+                    data = file.read()
+                    file_extension = FileExtension(Path(inner_file).suffix.lstrip("."))
+                    raw_files.append(
+                        cls(name=inner_file, contents=data, extension=file_extension)
+                    )
+            return raw_files
 
     @classmethod
     def from_database_blob(cls, blob_data: bytes, extension: FileExtension) -> RawFile:
@@ -601,6 +658,7 @@ class RawFile(msgspec.Struct, frozen=True, gc=False):
             "image/jpg": FileExtension.JPG,
             "text/html": FileExtension.HTML,
             "text/plain": FileExtension.TXT,
+            "application/x-zip-compressed": FileExtension.ZIP,
             # Add more mappings as needed
         }
         return content_type_map.get(content_type, None)
